@@ -12,7 +12,7 @@
 #' 
 #' @note Snow course locations, ID numbers, and other information can be found here: \url{http://cdec.water.ca.gov/misc/SnowCourses.html}
 #' 
-#' @return a `data.frame` object, see examples
+#' @return A `data.frame` with results from CDEC.
 #' 
 #' @references \url{http://cdec.water.ca.gov/cgi-progs/snowQuery}
 #' 
@@ -27,14 +27,15 @@ CDECsnowQuery <- function(course, start_yr, end_yr) {
     '&month=(All)&start_date=', start_yr, 
     '&end_date=', end_yr, 
     '&csv_mode=Y&data_wish=Retrieve+Data', 
-    sep='')
+    sep = ''
+  )
   
   # read the result of sending the URL as a CSV file:
   # noting that it has a header,
   # skipping the first line
   # not converting characters to factors
   # interpreting '        --' as NA
-  d <- read.csv(file=url(u), header=TRUE, skip=1, as.is=TRUE, na.strings='        --')
+  d <- read.csv(file = url(u), header = TRUE, skip = 1, as.is = TRUE, na.strings = '        --')
   
   if(nrow(d) == 0 | ncol(d) != 5)
     stop('query returned no data', call.=FALSE)
@@ -42,21 +43,26 @@ CDECsnowQuery <- function(course, start_yr, end_yr) {
   # compute the density, as percent
   d$density <- (d$Water / d$Depth) * 100.0
   
-  # add SWE collumn using Adjusted if present
+  # add SWE column using Adjusted if present
   d$SWE <- ifelse(is.na(d$Adjusted), d$Water, d$Adjusted)
   
   # convert date to R-friendly format
-  d$Meas.Date <- as.Date(d$Meas.Date, format="%d-%B-%Y")
+  d$Meas.Date <- as.Date(d$Meas.Date, format = "%d-%B-%Y")
   
   # convert representative date 
   # note that this month isn't the same as the month when the data were collected
   # note that we need to add an arbitrary 'day' to the string in order for it to be parsed correctly
-  d$Date <- as.Date(paste('01/', d$Date, sep=''), format="%d/%m/%Y")
+  d$Date <- as.Date(paste('01/', d$Date, sep = ''), format = "%d/%m/%Y")
   
   # extract the year and month for reporting ease later
+  .mo <- c('January','February','March','April','May','June','July','August','September','October','November','December')
   d$year <- as.numeric(format(d$Date, "%Y"))
-  d$month <- factor(format(d$Date, '%B'), levels=c('January','February','March','April','May','June','July','August','September','October','November','December'))
+  d$month <- factor(
+    format(d$Date, '%B'), 
+    levels = .mo
+  )
   
-  # return the result
-  return(d[, c('Meas.Date','Date','year','month','Depth','Water','Adjusted','SWE','density')])
+  # return a subset of columns, in specified order
+  d <- d[, c('Meas.Date','Date','year','month','Depth','Water','Adjusted','SWE','density')]
+  return(d)
 }
