@@ -3,11 +3,12 @@ context("vizHillslopePosition")
 ## tests
 library(aqp, quietly = TRUE)
 suppressWarnings(library(cluster, quietly = TRUE))
-suppressWarnings(library(dendextend, quietly = TRUE))
-suppressWarnings(library(latticeExtra, quietly = TRUE))
 
 test_that("vizHillslopePosition works as expected", {
   
+  skip_if_not_installed("dendextend")
+  skip_if_not_installed("latticeExtra")
+  
   # use local data
   data("OSDexamples")
   a <- OSDexamples$hillpos
